@@ -125,7 +125,9 @@ NULL
 #' @param type character, the type of software used to generate the abundances.
 #' Options are "salmon", "sailfish", "alevin", "kallisto", "rsem", "stringtie", or "none".
 #' This argument is used to autofill the arguments below (geneIdCol, etc.)
-#' "none" means that the user will specify these columns.
+#' "none" means that the user will specify these columns. Be aware that
+#' specifying \code{type} other than "none" will ignore the arguments below
+#' (geneIdCol, etc.)
 #' @param txIn logical, whether the incoming files are transcript level (default TRUE)
 #' @param txOut logical, whether the function should just output
 #' transcript-level (default FALSE)
@@ -172,9 +174,12 @@ NULL
 #' to remove version information to facilitate matching with the tx id in \code{tx2gene}
 #' (default FALSE)
 #' @param ignoreAfterBar logical, whether to split the tx id on the '|' character
-#' to facilitate matching with the tx id in \code{tx2gene} (default FALSE)
+#' to facilitate matching with the tx id in \code{tx2gene} (default FALSE).
+#' if \code{txOut=TRUE} it will strip the text after '|' on the rownames
+#' of the matrices
 #' @param geneIdCol name of column with gene id. if missing, the \code{tx2gene}
-#' argument can be used
+#' argument can be used. Note that this argument and the other four "...Col"
+#' arguments below are ignored unless \code{type="none"} 
 #' @param txIdCol name of column with tx id
 #' @param abundanceCol name of column with abundances (e.g. TPM or FPKM)
 #' @param countsCol name of column with estimated counts
@@ -263,31 +268,31 @@ tximport <- function(files,
                      sparseThreshold=1,
                      readLength=75,
                      alevinArgs=NULL) {
-
+  
   # inferential replicate importer
   infRepImporter <- NULL
-
+  
   type <- match.arg(type)
   countsFromAbundance <- match.arg(countsFromAbundance)
   if (countsFromAbundance == "dtuScaledTPM") {
     stopifnot(txOut)
     if (is.null(tx2gene)) stop("'dtuScaledTPM' requires 'tx2gene' input")
   }
-
+  
   if (!existenceOptional) stopifnot(all(file.exists(files)))
   if (!txIn & txOut) stop("txOut only an option when transcript-level data is read in (txIn=TRUE)")
-
+  
   stopifnot(length(files) > 0)
   kallisto.h5 <- basename(files[1]) == "abundance.h5"
   if (type == "kallisto" & !kallisto.h5) {
     message("Note: importing `abundance.h5` is typically faster than `abundance.tsv`")
   }
-
+  
   if (type=="rsem" & txIn & grepl("genes", files[1])) {
     message("It looks like you are importing RSEM genes.results files, setting txIn=FALSE")
     txIn <- FALSE
   }
-
+  
   # in order to use infRepStat, we need inf reps, and doesn't work with alevin or sparse code
   if (!is.null(infRepStat)) {
     if (dropInfReps) stop("infRepStat requires infReps")
@@ -340,8 +345,16 @@ tximport <- function(files,
       message("reading in files with read.delim (install 'readr' package for speed up)")
       importer <- read.delim
     } else {
-      message("reading in files with read_tsv")
-      readrStatus <- TRUE
+      # this fix contributed by @ATpoint
+      # readr won't work on very stripped down machines, e.g. Docker images w/o timezone
+      timeZoneMissing <- length(suppressWarnings(OlsonNames())) == 0 | is.na(Sys.timezone())
+      if (timeZoneMissing) {
+        message("reading in files with read.delim ('readr' installed but won't work w/o timezones)")
+        importer <- read.delim
+      } else {
+        message("reading in files with read_tsv")
+        readrStatus <- TRUE
+      }
     }
   }
   
@@ -359,7 +372,7 @@ tximport <- function(files,
     }
     infRepImporter <- if (dropInfReps) { NULL } else { function(x) readInfRepFish(x, type) }
   }
-
+  
   # kallisto presets
   if (type == "kallisto") {
     txIdCol <- "target_id"
@@ -405,7 +418,7 @@ tximport <- function(files,
       }
     }
   }
-
+  
   if (type == c("stringtie")) {
     txIdCol <- "t_name"
     geneIdCol <- "gene_name"
@@ -430,14 +443,15 @@ tximport <- function(files,
   # RSEM gene-level is the only case of !txIn
   if (!txIn) {
     txi <- computeRsemGeneLevel(files, importer, geneIdCol, abundanceCol, countsCol, lengthCol, countsFromAbundance)
+    message("")
     return(txi)
   }
-
+  
   # if external tx2gene table not provided, send user to vignette
   if (is.null(tx2gene) & !txOut) {
     summarizeFail() # ...long message in helper.R
   }
-
+  
   # trial run of inferential replicate info
   repInfo <- NULL
   if (infRepType != "none") {
@@ -461,7 +475,7 @@ txOut=TRUE, CFA either 'no' or 'scaledTPM', and no inferential replicates")
   
   ######################################################
   # the rest of the code assumes transcript-level input:
-
+  
   ### --- BEGIN --- loop over files reading in columns / inf reps ###
   for (i in seq_along(files)) {
     message(i," ",appendLF=FALSE)
@@ -531,7 +545,7 @@ txOut=TRUE, CFA either 'no' or 'scaledTPM', and no inferential replicates")
     }
   }
   ### --- END --- loop over files ###
-
+  
   # compile sparse matrices
   if (sparse) {
     countsMatTx <- Matrix::sparseMatrix(i=unlist(countsListI),
@@ -616,6 +630,13 @@ txOut=TRUE, CFA either 'no' or 'scaledTPM', and no inferential replicates")
                                             lengthMat=length4CFA,
                                             countsFromAbundance=countsFromAbundance)
     }
+    # request from Issue 40: remove text after '|' for txOut=TRUE
+    if (ignoreAfterBar) {
+      for (matNm in c("counts","abundance","length")) {
+        rowNms <- rownames(txi[[matNm]])
+        rownames(txi[[matNm]]) <- sub("\\|.*", "", rowNms)
+      }
+    }
     return(txi)
   }
   
